# bonk

## What is bonk?

bonk is a very simple IPAM- and DNS-management Django app. It keeps
track of your logical network structure, your physical networks, and
the IP addresses used within them. It also keeps track of your
domains and the records contained therein.

## How do I install it?

See [the installation documentation](INSTALL.md).

## How do I use it?

See [the howto](HOWTO.md).
